@@ -3,8 +3,8 @@ package chezmoi
 // An Encryption encrypts and decrypts files and data.
 type Encryption interface {
 	Decrypt(ciphertext []byte) ([]byte, error)
-	DecryptToFile(plaintextFilename string, ciphertext []byte) error
+	DecryptToFile(plaintextFilename AbsPath, ciphertext []byte) error
 	Encrypt(plaintext []byte) ([]byte, error)
-	EncryptFile(plaintextFilename string) ([]byte, error)
+	EncryptFile(plaintextFilename AbsPath) ([]byte, error)
 	EncryptedSuffix() string
 }
