@@ -13,8 +13,16 @@ type RealSystem struct {
 	fileSystem vfs.FS
 }
 
+// RealSystemWithSafe sets the safe flag of the RealSystem. On Windows it does
+// nothing as Windows does not support atomic file or symlink updates. See
+// https://github.com/google/renameio/issues/1 and
+// https://github.com/golang/go/issues/22397#issuecomment-498856679.
+func RealSystemWithSafe(safe bool) RealSystemOption {
+	return func(s *RealSystem) {}
+}
+
 // NewRealSystem returns a System that acts on fs.
-func NewRealSystem(fileSystem vfs.FS) *RealSystem {
+func NewRealSystem(fileSystem vfs.FS, options ...RealSystemOption) *RealSystem {
 	return &RealSystem{
 		fileSystem: fileSystem,
 	}
