@@ -3,6 +3,7 @@ package chezmoi
 import (
 	"archive/zip"
 	"bytes"
+	"context"
 	"io"
 	"io/fs"
 	"testing"
@@ -34,12 +35,14 @@ func TestZIPWriterSystem(t *testing.T) {
 			"symlink_symlink": ".dir/subdir/file\n",
 		},
 	}, func(fileSystem vfs.FS) {
+		ctx := context.Background()
 		system := NewRealSystem(fileSystem)
 		s := NewSourceState(
+			WithBaseSystem(system),
 			WithSourceDir("/home/user/.local/share/chezmoi"),
 			WithSystem(system),
 		)
-		require.NoError(t, s.Read())
+		require.NoError(t, s.Read(ctx, nil))
 		requireEvaluateAll(t, s, system)
 
 		b := &bytes.Buffer{}
