@@ -80,7 +80,7 @@ func (c *Config) defaultPreAddFunc(targetRelPath chezmoi.RelPath, newSourceState
 	if len(removedAttributes) == 0 {
 		return nil
 	}
-	removedAttributesStr := englishList(removedAttributes, "attribute", "")
+	removedAttributesStr := englishListWithNoun(removedAttributes, "attribute", "")
 
 	for {
 		switch choice, err := c.promptChoice(fmt.Sprintf("adding %s would remove %s, continue", targetRelPath, removedAttributesStr), yesNoAllQuit); {
@@ -92,7 +92,7 @@ func (c *Config) defaultPreAddFunc(targetRelPath chezmoi.RelPath, newSourceState
 		case choice == "no":
 			return chezmoi.Skip
 		case choice == "quit":
-			return ErrExitCode(1)
+			return ExitCodeError(1)
 		case choice == "yes":
 			return nil
 		default:
