@@ -30,6 +30,10 @@ func TestAddCmd(t *testing.T) {
 					vfst.TestIsDir,
 					vfst.TestModePerm(0o777&^chezmoitest.Umask),
 				),
+				vfst.TestPath("/home/user/.local/share/chezmoi/dot_dir/.keep",
+					vfst.TestContents(nil),
+					vfst.TestModePerm(0o666&^chezmoitest.Umask),
+				),
 			},
 		},
 		{
@@ -50,6 +54,10 @@ func TestAddCmd(t *testing.T) {
 					vfst.TestIsDir,
 					vfst.TestModePerm(0o777&^chezmoitest.Umask),
 				),
+				vfst.TestPath("/home/user/.local/share/chezmoi/dot_dir/.keep",
+					vfst.TestContents(nil),
+					vfst.TestModePerm(0o666&^chezmoitest.Umask),
+				),
 				vfst.TestPath("/home/user/.local/share/chezmoi/dot_dir/file",
 					vfst.TestModeIsRegular,
 					vfst.TestModePerm(0o666&^chezmoitest.Umask),
@@ -75,6 +83,10 @@ func TestAddCmd(t *testing.T) {
 					vfst.TestIsDir,
 					vfst.TestModePerm(0o777&^chezmoitest.Umask),
 				),
+				vfst.TestPath("/home/user/.local/share/chezmoi/dot_dir/.keep",
+					vfst.TestContents(nil),
+					vfst.TestModePerm(0o666&^chezmoitest.Umask),
+				),
 				vfst.TestPath("/home/user/.local/share/chezmoi/dot_dir/file",
 					vfst.TestDoesNotExist,
 				),
@@ -98,6 +110,10 @@ func TestAddCmd(t *testing.T) {
 					vfst.TestIsDir,
 					vfst.TestModePerm(0o777&^chezmoitest.Umask),
 				),
+				vfst.TestPath("/home/user/.local/share/chezmoi/private_dot_dir/.keep",
+					vfst.TestContents(nil),
+					vfst.TestModePerm(0o666&^chezmoitest.Umask),
+				),
 				vfst.TestPath("/home/user/.local/share/chezmoi/private_dot_dir/file",
 					vfst.TestModeIsRegular,
 					vfst.TestModePerm(0o666&^chezmoitest.Umask),
@@ -123,6 +139,10 @@ func TestAddCmd(t *testing.T) {
 					vfst.TestIsDir,
 					vfst.TestModePerm(0o777&^chezmoitest.Umask),
 				),
+				vfst.TestPath("/home/user/.local/share/chezmoi/private_dot_dir/.keep",
+					vfst.TestContents(nil),
+					vfst.TestModePerm(0o666&^chezmoitest.Umask),
+				),
 				vfst.TestPath("/home/user/.local/share/chezmoi/private_dot_dir/file",
 					vfst.TestModeIsRegular,
 					vfst.TestModePerm(0o666&^chezmoitest.Umask),
