@@ -61,7 +61,7 @@ type Config struct {
 	Interpreters     map[string]*chezmoi.Interpreter `mapstructure:"interpreters"`
 	Mode             chezmoi.Mode                    `mapstructure:"mode"`
 	Pager            string                          `mapstructure:"pager"`
-	Remove           bool                            `mapstructure:"remove"`
+	Safe             bool                            `mapstructure:"safe"`
 	SourceDirAbsPath chezmoi.AbsPath                 `mapstructure:"sourceDir"`
 	Template         templateConfig                  `mapstructure:"template"`
 	Umask            fs.FileMode                     `mapstructure:"umask"`
@@ -216,6 +216,7 @@ func newConfig(options ...configOption) (*Config, error) {
 		},
 		Interpreters: defaultInterpreters,
 		Pager:        os.Getenv("PAGER"),
+		Safe:         true,
 		Template: templateConfig{
 			Options: chezmoi.DefaultTemplateOptions,
 		},
@@ -579,6 +580,13 @@ func (c *Config) defaultConfigFile(fileSystem vfs.Stater, bds *xdg.BaseDirectory
 }
 
 func (c *Config) defaultPreApplyFunc(targetRelPath chezmoi.RelPath, targetEntryState, lastWrittenEntryState, actualEntryState *chezmoi.EntryState) error {
+	log.Debug().
+		Stringer("targetRelPath", targetRelPath).
+		Object("targetEntryState", targetEntryState).
+		Object("lastWrittenEntryState", lastWrittenEntryState).
+		Object("actualEntryState", actualEntryState).
+		Msg("defaultPreApplyFunc")
+
 	switch {
 	case targetEntryState.Overwrite():
 		return nil
@@ -1023,7 +1031,7 @@ func (c *Config) newRootCmd() (*cobra.Command, error) {
 
 	persistentFlags.Var(&c.Color, "color", "Colorize output")
 	persistentFlags.VarP(&c.DestDirAbsPath, "destination", "D", "Set destination directory")
-	persistentFlags.BoolVar(&c.Remove, "remove", c.Remove, "Remove entries from destination directory")
+	persistentFlags.BoolVar(&c.Safe, "safe", c.Safe, "Safely replace files and symlinks")
 	persistentFlags.VarP(&c.SourceDirAbsPath, "source", "S", "Set source directory")
 	persistentFlags.Var(&c.Mode, "mode", "Mode")
 	persistentFlags.Var(&c.UseBuiltinGit, "use-builtin-git", "Use builtin git")
@@ -1031,7 +1039,6 @@ func (c *Config) newRootCmd() (*cobra.Command, error) {
 		"color",
 		"destination",
 		"mode",
-		"remove",
 		"source",
 	} {
 		if err := viper.BindPFlag(key, persistentFlags.Lookup(key)); err != nil {
@@ -1061,6 +1068,7 @@ func (c *Config) newRootCmd() (*cobra.Command, error) {
 		rootCmd.MarkPersistentFlagDirname("destination"),
 		persistentFlags.MarkHidden("gops"),
 		rootCmd.MarkPersistentFlagFilename("output"),
+		persistentFlags.MarkHidden("safe"),
 		rootCmd.MarkPersistentFlagDirname("source"),
 	} {
 		if err != nil {
@@ -1260,7 +1268,14 @@ func (c *Config) persistentPreRunRootE(cmd *cobra.Command, args []string) error
 		zerolog.SetGlobalLevel(zerolog.Disabled)
 	}
 
-	c.baseSystem = chezmoi.NewRealSystem(c.fileSystem)
+	log.Debug().
+		Object("version", c.versionInfo).
+		Strs("args", args).
+		Msg("persistentPreRunRootE")
+
+	c.baseSystem = chezmoi.NewRealSystem(c.fileSystem,
+		chezmoi.RealSystemWithSafe(c.Safe),
+	)
 	if c.debug {
 		c.baseSystem = chezmoi.NewDebugSystem(c.baseSystem)
 	}
